@@ -1,8 +1,10 @@
+#![allow(clippy::integer_arithmetic)]
 use {
     solana_cli::{
+        check_balance,
         cli::{process_command, request_and_confirm_airdrop, CliCommand, CliConfig},
         spend_utils::SpendAmount,
-        test_utils::{check_ready, check_recent_balance},
+        test_utils::check_ready,
     },
     solana_cli_output::{parse_sign_only_reply_string, OutputFormat},
     solana_client::{
@@ -14,6 +16,7 @@ use {
     solana_sdk::{
         commitment_config::CommitmentConfig,
         hash::Hash,
+        native_token::sol_to_lamports,
         pubkey::Pubkey,
         signature::{keypair_from_seed, Keypair, Signer},
         system_program,
@@ -73,10 +76,14 @@ fn full_battery_tests(
         &rpc_client,
         &config_payer,
         &config_payer.signers[0].pubkey(),
-        2000,
+        sol_to_lamports(2000.0),
     )
     .unwrap();
-    check_recent_balance(2000, &rpc_client, &config_payer.signers[0].pubkey());
+    check_balance!(
+        sol_to_lamports(2000.0),
+        &rpc_client,
+        &config_payer.signers[0].pubkey(),
+    );
 
     let mut config_nonce = CliConfig::recent_for_tests();
     config_nonce.json_rpc_url = json_rpc_url;
@@ -108,12 +115,16 @@ fn full_battery_tests(
         seed,
         nonce_authority: optional_authority,
         memo: None,
-        amount: SpendAmount::Some(1000),
+        amount: SpendAmount::Some(sol_to_lamports(1000.0)),
     };
 
     process_command(&config_payer).unwrap();
-    check_recent_balance(1000, &rpc_client, &config_payer.signers[0].pubkey());
-    check_recent_balance(1000, &rpc_client, &nonce_account);
+    check_balance!(
+        sol_to_lamports(1000.0),
+        &rpc_client,
+        &config_payer.signers[0].pubkey(),
+    );
+    check_balance!(sol_to_lamports(1000.0), &rpc_client, &nonce_account);
 
     // Get nonce
     config_payer.signers.pop();
@@ -161,12 +172,16 @@ fn full_battery_tests(
         nonce_authority: index,
         memo: None,
         destination_account_pubkey: payee_pubkey,
-        lamports: 100,
+        lamports: sol_to_lamports(100.0),
     };
     process_command(&config_payer).unwrap();
-    check_recent_balance(1000, &rpc_client, &config_payer.signers[0].pubkey());
-    check_recent_balance(900, &rpc_client, &nonce_account);
-    check_recent_balance(100, &rpc_client, &payee_pubkey);
+    check_balance!(
+        sol_to_lamports(1000.0),
+        &rpc_client,
+        &config_payer.signers[0].pubkey(),
+    );
+    check_balance!(sol_to_lamports(900.0), &rpc_client, &nonce_account);
+    check_balance!(sol_to_lamports(100.0), &rpc_client, &payee_pubkey);
 
     // Show nonce account
     config_payer.command = CliCommand::ShowNonceAccount {
@@ -208,12 +223,16 @@ fn full_battery_tests(
         nonce_authority: 1,
         memo: None,
         destination_account_pubkey: payee_pubkey,
-        lamports: 100,
+        lamports: sol_to_lamports(100.0),
     };
     process_command(&config_payer).unwrap();
-    check_recent_balance(1000, &rpc_client, &config_payer.signers[0].pubkey());
-    check_recent_balance(800, &rpc_client, &nonce_account);
-    check_recent_balance(200, &rpc_client, &payee_pubkey);
+    check_balance!(
+        sol_to_lamports(1000.0),
+        &rpc_client,
+        &config_payer.signers[0].pubkey(),
+    );
+    check_balance!(sol_to_lamports(800.0), &rpc_client, &nonce_account);
+    check_balance!(sol_to_lamports(200.0), &rpc_client, &payee_pubkey);
 }
 
 #[test]
@@ -241,19 +260,27 @@ fn test_create_account_with_seed() {
         &rpc_client,
         &CliConfig::recent_for_tests(),
         &offline_nonce_authority_signer.pubkey(),
-        42,
+        sol_to_lamports(42.0),
     )
     .unwrap();
     request_and_confirm_airdrop(
         &rpc_client,
         &CliConfig::recent_for_tests(),
         &online_nonce_creator_signer.pubkey(),
-        4242,
+        sol_to_lamports(4242.0),
     )
     .unwrap();
-    check_recent_balance(42, &rpc_client, &offline_nonce_authority_signer.pubkey());
-    check_recent_balance(4242, &rpc_client, &online_nonce_creator_signer.pubkey());
-    check_recent_balance(0, &rpc_client, &to_address);
+    check_balance!(
+        sol_to_lamports(42.0),
+        &rpc_client,
+        &offline_nonce_authority_signer.pubkey(),
+    );
+    check_balance!(
+        sol_to_lamports(4242.0),
+        &rpc_client,
+        &online_nonce_creator_signer.pubkey(),
+    );
+    check_balance!(0, &rpc_client, &to_address);
 
     check_ready(&rpc_client);
 
@@ -263,7 +290,7 @@ fn test_create_account_with_seed() {
     let seed = authority_pubkey.to_string()[0..32].to_string();
     let nonce_address =
         Pubkey::create_with_seed(&creator_pubkey, &seed, &system_program::id()).unwrap();
-    check_recent_balance(0, &rpc_client, &nonce_address);
+    check_balance!(0, &rpc_client, &nonce_address);
 
     let mut creator_config = CliConfig::recent_for_tests();
     creator_config.json_rpc_url = test_validator.rpc_url();
@@ -273,13 +300,21 @@ fn test_create_account_with_seed() {
         seed: Some(seed),
         nonce_authority: Some(authority_pubkey),
         memo: None,
-        amount: SpendAmount::Some(241),
+        amount: SpendAmount::Some(sol_to_lamports(241.0)),
     };
     process_command(&creator_config).unwrap();
-    check_recent_balance(241, &rpc_client, &nonce_address);
-    check_recent_balance(42, &rpc_client, &offline_nonce_authority_signer.pubkey());
-    check_recent_balance(4000, &rpc_client, &online_nonce_creator_signer.pubkey());
-    check_recent_balance(0, &rpc_client, &to_address);
+    check_balance!(sol_to_lamports(241.0), &rpc_client, &nonce_address);
+    check_balance!(
+        sol_to_lamports(42.0),
+        &rpc_client,
+        &offline_nonce_authority_signer.pubkey(),
+    );
+    check_balance!(
+        sol_to_lamports(4000.999999999),
+        &rpc_client,
+        &online_nonce_creator_signer.pubkey(),
+    );
+    check_balance!(0, &rpc_client, &to_address);
 
     // Fetch nonce hash
     let nonce_hash = nonce_utils::get_account_with_commitment(
@@ -299,7 +334,7 @@ fn test_create_account_with_seed() {
     authority_config.command = CliCommand::ClusterVersion;
     process_command(&authority_config).unwrap_err();
     authority_config.command = CliCommand::Transfer {
-        amount: SpendAmount::Some(10),
+        amount: SpendAmount::Some(sol_to_lamports(10.0)),
         to: to_address,
         from: 0,
         sign_only: true,
@@ -325,7 +360,7 @@ fn test_create_account_with_seed() {
     submit_config.json_rpc_url = test_validator.rpc_url();
     submit_config.signers = vec![&authority_presigner];
     submit_config.command = CliCommand::Transfer {
-        amount: SpendAmount::Some(10),
+        amount: SpendAmount::Some(sol_to_lamports(10.0)),
         to: to_address,
         from: 0,
         sign_only: false,
@@ -344,8 +379,16 @@ fn test_create_account_with_seed() {
         derived_address_program_id: None,
     };
     process_command(&submit_config).unwrap();
-    check_recent_balance(241, &rpc_client, &nonce_address);
-    check_recent_balance(31, &rpc_client, &offline_nonce_authority_signer.pubkey());
-    check_recent_balance(4000, &rpc_client, &online_nonce_creator_signer.pubkey());
-    check_recent_balance(10, &rpc_client, &to_address);
+    check_balance!(sol_to_lamports(241.0), &rpc_client, &nonce_address);
+    check_balance!(
+        sol_to_lamports(31.999999999),
+        &rpc_client,
+        &offline_nonce_authority_signer.pubkey(),
+    );
+    check_balance!(
+        sol_to_lamports(4000.999999999),
+        &rpc_client,
+        &online_nonce_creator_signer.pubkey(),
+    );
+    check_balance!(sol_to_lamports(10.0), &rpc_client, &to_address);
 }
