@@ -1,10 +1,12 @@
+#![allow(clippy::integer_arithmetic)]
 #![allow(clippy::redundant_closure)]
 use {
     solana_cli::{
+        check_balance,
         cli::{process_command, request_and_confirm_airdrop, CliCommand, CliConfig},
         spend_utils::SpendAmount,
         stake::StakeAuthorizationIndexed,
-        test_utils::{check_ready, check_recent_balance},
+        test_utils::check_ready,
     },
     solana_cli_output::{parse_sign_only_reply_string, OutputFormat},
     solana_client::{
@@ -150,7 +152,7 @@ fn test_seed_stake_delegation_and_deactivation() {
         100_000,
     )
     .unwrap();
-    check_recent_balance(100_000, &rpc_client, &config_validator.signers[0].pubkey());
+    check_balance!(100_000, &rpc_client, &config_validator.signers[0].pubkey());
 
     let stake_address = Pubkey::create_with_seed(
         &config_validator.signers[0].pubkey(),
@@ -239,7 +241,7 @@ fn test_stake_delegation_and_deactivation() {
         100_000,
     )
     .unwrap();
-    check_recent_balance(100_000, &rpc_client, &config_validator.signers[0].pubkey());
+    check_balance!(100_000, &rpc_client, &config_validator.signers[0].pubkey());
 
     // Create stake account
     config_validator.signers.push(&stake_keypair);
@@ -333,7 +335,7 @@ fn test_offline_stake_delegation_and_deactivation() {
         100_000,
     )
     .unwrap();
-    check_recent_balance(100_000, &rpc_client, &config_validator.signers[0].pubkey());
+    check_balance!(100_000, &rpc_client, &config_validator.signers[0].pubkey());
 
     request_and_confirm_airdrop(
         &rpc_client,
@@ -342,7 +344,7 @@ fn test_offline_stake_delegation_and_deactivation() {
         100_000,
     )
     .unwrap();
-    check_recent_balance(100_000, &rpc_client, &config_offline.signers[0].pubkey());
+    check_balance!(100_000, &rpc_client, &config_offline.signers[0].pubkey());
 
     // Create stake account
     config_validator.signers.push(&stake_keypair);
@@ -911,13 +913,13 @@ fn test_stake_authorize_with_fee_payer() {
     process_command(&config_offline).unwrap_err();
 
     request_and_confirm_airdrop(&rpc_client, &config, &default_pubkey, 100_000).unwrap();
-    check_recent_balance(100_000, &rpc_client, &config.signers[0].pubkey());
+    check_balance!(100_000, &rpc_client, &config.signers[0].pubkey());
 
     request_and_confirm_airdrop(&rpc_client, &config_payer, &payer_pubkey, 100_000).unwrap();
-    check_recent_balance(100_000, &rpc_client, &payer_pubkey);
+    check_balance!(100_000, &rpc_client, &payer_pubkey);
 
     request_and_confirm_airdrop(&rpc_client, &config_offline, &offline_pubkey, 100_000).unwrap();
-    check_recent_balance(100_000, &rpc_client, &offline_pubkey);
+    check_balance!(100_000, &rpc_client, &offline_pubkey);
 
     check_ready(&rpc_client);
 
@@ -944,7 +946,7 @@ fn test_stake_authorize_with_fee_payer() {
     };
     process_command(&config).unwrap();
     // `config` balance should be 50,000 - 1 stake account sig - 1 fee sig
-    check_recent_balance(50_000 - SIG_FEE - SIG_FEE, &rpc_client, &default_pubkey);
+    check_balance!(50_000 - SIG_FEE - SIG_FEE, &rpc_client, &default_pubkey);
 
     // Assign authority with separate fee payer
     config.signers = vec![&default_signer, &payer_keypair];
@@ -968,10 +970,10 @@ fn test_stake_authorize_with_fee_payer() {
     };
     process_command(&config).unwrap();
     // `config` balance has not changed, despite submitting the TX
-    check_recent_balance(50_000 - SIG_FEE - SIG_FEE, &rpc_client, &default_pubkey);
+    check_balance!(50_000 - SIG_FEE - SIG_FEE, &rpc_client, &default_pubkey);
     // `config_payer` however has paid `config`'s authority sig
     // and `config_payer`'s fee sig
-    check_recent_balance(100_000 - SIG_FEE - SIG_FEE, &rpc_client, &payer_pubkey);
+    check_balance!(100_000 - SIG_FEE - SIG_FEE, &rpc_client, &payer_pubkey);
 
     // Assign authority with offline fee payer
     let blockhash = rpc_client.get_latest_blockhash().unwrap();
@@ -1019,10 +1021,10 @@ fn test_stake_authorize_with_fee_payer() {
     };
     process_command(&config).unwrap();
     // `config`'s balance again has not changed
-    check_recent_balance(50_000 - SIG_FEE - SIG_FEE, &rpc_client, &default_pubkey);
+    check_balance!(50_000 - SIG_FEE - SIG_FEE, &rpc_client, &default_pubkey);
     // `config_offline` however has paid 1 sig due to being both authority
     // and fee payer
-    check_recent_balance(100_000 - SIG_FEE, &rpc_client, &offline_pubkey);
+    check_balance!(100_000 - SIG_FEE, &rpc_client, &offline_pubkey);
 }
 
 #[test]
@@ -1058,10 +1060,10 @@ fn test_stake_split() {
 
     request_and_confirm_airdrop(&rpc_client, &config, &config.signers[0].pubkey(), 500_000)
         .unwrap();
-    check_recent_balance(500_000, &rpc_client, &config.signers[0].pubkey());
+    check_balance!(500_000, &rpc_client, &config.signers[0].pubkey());
 
     request_and_confirm_airdrop(&rpc_client, &config_offline, &offline_pubkey, 100_000).unwrap();
-    check_recent_balance(100_000, &rpc_client, &offline_pubkey);
+    check_balance!(100_000, &rpc_client, &offline_pubkey);
 
     // Create stake account, identity is authority
     let minimum_stake_balance = rpc_client
@@ -1088,7 +1090,7 @@ fn test_stake_split() {
         from: 0,
     };
     process_command(&config).unwrap();
-    check_recent_balance(
+    check_balance!(
         10 * minimum_stake_balance,
         &rpc_client,
         &stake_account_pubkey,
@@ -1108,7 +1110,7 @@ fn test_stake_split() {
         amount: SpendAmount::Some(minimum_nonce_balance),
     };
     process_command(&config).unwrap();
-    check_recent_balance(minimum_nonce_balance, &rpc_client, &nonce_account.pubkey());
+    check_balance!(minimum_nonce_balance, &rpc_client, &nonce_account.pubkey());
 
     // Fetch nonce hash
     let nonce_hash = nonce_utils::get_account_with_commitment(
@@ -1122,7 +1124,7 @@ fn test_stake_split() {
 
     // Nonced offline split
     let split_account = keypair_from_seed(&[2u8; 32]).unwrap();
-    check_recent_balance(0, &rpc_client, &split_account.pubkey());
+    check_balance!(0, &rpc_client, &split_account.pubkey());
     config_offline.signers.push(&split_account);
     config_offline.command = CliCommand::SplitStake {
         stake_account_pubkey,
@@ -1162,12 +1164,12 @@ fn test_stake_split() {
         fee_payer: 0,
     };
     process_command(&config).unwrap();
-    check_recent_balance(
+    check_balance!(
         8 * minimum_stake_balance,
         &rpc_client,
         &stake_account_pubkey,
     );
-    check_recent_balance(
+    check_balance!(
         2 * minimum_stake_balance,
         &rpc_client,
         &split_account.pubkey(),
@@ -1207,10 +1209,10 @@ fn test_stake_set_lockup() {
 
     request_and_confirm_airdrop(&rpc_client, &config, &config.signers[0].pubkey(), 500_000)
         .unwrap();
-    check_recent_balance(500_000, &rpc_client, &config.signers[0].pubkey());
+    check_balance!(500_000, &rpc_client, &config.signers[0].pubkey());
 
     request_and_confirm_airdrop(&rpc_client, &config_offline, &offline_pubkey, 100_000).unwrap();
-    check_recent_balance(100_000, &rpc_client, &offline_pubkey);
+    check_balance!(100_000, &rpc_client, &offline_pubkey);
 
     // Create stake account, identity is authority
     let minimum_stake_balance = rpc_client
@@ -1244,7 +1246,12 @@ fn test_stake_set_lockup() {
         from: 0,
     };
     process_command(&config).unwrap();
-    check_recent_balance(
+    check_balance!(
+        10 * minimum_stake_balance,
+        &rpc_client,
+        &stake_account_pubkey,
+    );
+    check_balance!(
         10 * minimum_stake_balance,
         &rpc_client,
         &stake_account_pubkey,
@@ -1377,7 +1384,7 @@ fn test_stake_set_lockup() {
         amount: SpendAmount::Some(minimum_nonce_balance),
     };
     process_command(&config).unwrap();
-    check_recent_balance(minimum_nonce_balance, &rpc_client, &nonce_account_pubkey);
+    check_balance!(minimum_nonce_balance, &rpc_client, &nonce_account_pubkey);
 
     // Fetch nonce hash
     let nonce_hash = nonce_utils::get_account_with_commitment(
@@ -1473,10 +1480,10 @@ fn test_offline_nonced_create_stake_account_and_withdraw() {
 
     request_and_confirm_airdrop(&rpc_client, &config, &config.signers[0].pubkey(), 200_000)
         .unwrap();
-    check_recent_balance(200_000, &rpc_client, &config.signers[0].pubkey());
+    check_balance!(200_000, &rpc_client, &config.signers[0].pubkey());
 
     request_and_confirm_airdrop(&rpc_client, &config_offline, &offline_pubkey, 100_000).unwrap();
-    check_recent_balance(100_000, &rpc_client, &offline_pubkey);
+    check_balance!(100_000, &rpc_client, &offline_pubkey);
 
     // Create nonce account
     let minimum_nonce_balance = rpc_client
@@ -1553,7 +1560,7 @@ fn test_offline_nonced_create_stake_account_and_withdraw() {
         from: 0,
     };
     process_command(&config).unwrap();
-    check_recent_balance(50_000, &rpc_client, &stake_pubkey);
+    check_balance!(50_000, &rpc_client, &stake_pubkey);
 
     // Fetch nonce hash
     let nonce_hash = nonce_utils::get_account_with_commitment(
@@ -1572,7 +1579,7 @@ fn test_offline_nonced_create_stake_account_and_withdraw() {
     config_offline.command = CliCommand::WithdrawStake {
         stake_account_pubkey: stake_pubkey,
         destination_account_pubkey: recipient_pubkey,
-        amount: SpendAmount::Some(42),
+        amount: SpendAmount::Some(50_000),
         withdraw_authority: 0,
         custodian: None,
         sign_only: true,
@@ -1591,7 +1598,7 @@ fn test_offline_nonced_create_stake_account_and_withdraw() {
     config.command = CliCommand::WithdrawStake {
         stake_account_pubkey: stake_pubkey,
         destination_account_pubkey: recipient_pubkey,
-        amount: SpendAmount::Some(42),
+        amount: SpendAmount::Some(50_000),
         withdraw_authority: 0,
         custodian: None,
         sign_only: false,
@@ -1607,7 +1614,7 @@ fn test_offline_nonced_create_stake_account_and_withdraw() {
         fee_payer: 0,
     };
     process_command(&config).unwrap();
-    check_recent_balance(42, &rpc_client, &recipient_pubkey);
+    check_balance!(50_000, &rpc_client, &recipient_pubkey);
 
     // Fetch nonce hash
     let nonce_hash = nonce_utils::get_account_with_commitment(
@@ -1667,7 +1674,7 @@ fn test_offline_nonced_create_stake_account_and_withdraw() {
     process_command(&config).unwrap();
     let seed_address =
         Pubkey::create_with_seed(&stake_pubkey, seed, &stake::program::id()).unwrap();
-    check_recent_balance(50_000, &rpc_client, &seed_address);
+    check_balance!(50_000, &rpc_client, &seed_address);
 }
 
 #[test]
